@@ -1101,9 +1101,10 @@ def sparse_get_pairs(n, env):
 #    int py_sparse_get_tuples(int* out_tuples, double* out_v, struct fm_env_sparse* env)
 def sparse_get_tuples(env):
     trace( "int py_sparse_get_tuples(int* out_tuples, double* out_v, struct fm_env_sparse* env)")
-    n = fm.py_get_num_tuples(env)
-    pout_tuplesnp, pout_tuples = create_intc_zeros_as_CFFI_int( 2 ** n)
-    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( 2 ** n)
+    n_tup = fm.py_get_num_tuples( env)
+    size_tup = fm.py_get_sizearray_tuples( env) 
+    pout_tuplesnp, pout_tuples = create_intc_zeros_as_CFFI_int( n_tup)
+    pout_vnp, pout_v = create_float_zeros_as_CFFI_double( size_tup)
     yy = fm.py_sparse_get_tuples( pout_tuples, pout_v, env)
     return pout_tuplesnp, pout_vnp
 
